Closed Bug 110924 Opened 24 years ago Closed 24 years ago

HTMLContentSink::AddAttributes() and nsGHE::IsEventName() speedups...

Categories

(Core :: DOM: Core & HTML, defect)

defect
Not set
normal

Tracking

()

RESOLVED FIXED
mozilla0.9.7

People

(Reporter: jst, Assigned: jst)

Details

(Whiteboard: [HAVE FIX])

Attachments

(1 file)

The methods HTMLContentSink::AddAttributes() and nsGHE::IsEventName() can be sped up, too much string copying n' stuff... Patch coming up.
Attached patch Speedups... — — Splinter Review
This patch makes HTMLContentSink::GetAttributeValueAt() about 3 times faster and also makes nsGenericHTMLElement::IsEventName() about 42% faster. These changes cuts out about 8% of the time we spend in HTMLContentSink::AddAttributes().
Status: NEW → ASSIGNED
Whiteboard: [HAVE FIX]
Target Milestone: --- → mozilla0.9.7
Comment on attachment 58501 [details] [diff] [review] Speedups... r=bzbarsky
Attachment #58501 - Flags: review+
Initial pageload tests (in viewer, single run) shows that after is about 1.5% faster than before. Waterson, sr=?
Oh, I forgot a |const| in fron of the return type for GetAttributeValueAt(), added locally.
Comment on attachment 58501 [details] [diff] [review] Speedups... sr=waterson
Attachment #58501 - Flags: superreview+
Fixed.
Status: ASSIGNED → RESOLVED
Closed: 24 years ago
Resolution: --- → FIXED
Component: DOM: HTML → DOM: Core & HTML
QA Contact: stummala → general
You need to log in before you can comment on or make changes to this bug.

Attachment

General

Created:
Updated:
Size: